# chefkoch
[![Version](https://img.shields.io/pypi/v/chefkoch.svg)](https://pypi.python.org/pypi/chefkoch)
[![Status](https://img.shields.io/pypi/status/chefkoch.svg)](https://pypi.python.org/pypi/chefkoch)
[![Python wheels](https://img.shields.io/pypi/wheel/chefkoch.svg)](https://pypi.python.org/pypi/chefkoch)
[![Documentation Status](https://readthedocs.org/projects/chefkoch/badge/?version=latest)](http://chefkoch.readthedocs.io/en/latest/?badge=latest)

[![License](https://img.shields.io/pypi/l/chefkoch.svg)](https://pypi.python.org/pypi/chefkoch)
[![Python versions](https://img.shields.io/pypi/pyversions/chefkoch.svg)](https://pypi.python.org/pypi/chefkoch)
[![Implementation](https://img.shields.io/pypi/implementation/chefkoch.svg)](https://pypi.python.org/pypi/chefkoch)

[![Coverage Status](https://coveralls.io/repos/github/EMS-TU-Ilmenau/chefkoch/badge.svg?branch=master)](https://coveralls.io/github/EMS-TU-Ilmenau/chefkoch?branch=master)
[![GitHub issues](https://img.shields.io/github/issues/EMS-TU-Ilmenau/chefkoch.svg)](https://github.com/EMS-TU-Ilmenau/chefkoch/issues)
**stable:** [![Build Status](https://www.travis-ci.org/EMS-TU-Ilmenau/chefkoch.svg?branch=stable)](https://www.travis-ci.org/EMS-TU-Ilmenau/chefkoch) **master:** [![Build Status](https://www.travis-ci.org/EMS-TU-Ilmenau/chefkoch.svg?branch=master)](https://www.travis-ci.org/EMS-TU-Ilmenau/chefkoch)

## Description
A compute cluster cuisine for distributed scientific computing in python

### Dependencies
- Python >= 2.7 or >=3.5
- dask 

### Authors & Contact Information
- Christoph Wagner | christoph.wagner@tu-ilmenau.de
  Technische Universität Ilmenau, Institute for Information Technology, EMS Group
- **<https://www.tu-ilmenau.de/it-ems/>**

## Documentation / HELP !
Please have a look at the documentation, which is included in the source
distribution at github or may be built locally on your machine by running
    `make doc`

If you experience any trouble please do not hesitate to contact us or to open
an issue on our github projectpage: https://github.com/EMS-TU-Ilmenau/chefkoch

### FAQ

Please check out our project documentation at [readthedocs](https://chefkoch.readthedocs.io/).

#### Issue not resolved yet?
Please contact us or leave your bug report in the *issue* section. Thank You!
